# Setup

Install Python
Install UV 
Have a wallabag instance to work against
uv venv activate 

## Quality of Life Commands 

Run `uv run task --list` to see which commands exist that improve the developer experience.

